import React, { Suspense } from 'react'
import { Physics } from '@react-three/cannon'
import { Stats } from '@react-three/drei'

import World from './models/World'
import WorldCollisions from './models/WorldCollisions'
import Player from './Player'
import Lighting from './Lighting'
import Effects from './Effects'
import Controls from './Controls'
import Users from './Users'

const Scene: React.FC = () => {
  return (
    <>
      <Stats />
      <Lighting />

      <Suspense fallback={null}>
        <World />
        <Physics
          gravity={[0, 0, 0]}
          tolerance={0}
          iterations={2}
          size={2}
          broadphase="SAP"
          axisIndex={1}
          defaultContactMaterial={{
            friction: 0,
            restitution: 0,
          }}
        >
          <WorldCollisions />
          <Player />
        </Physics>
        <Effects />
      </Suspense>
      <Users />

      <Controls />
    </>
  )
}

export default Scene
